@@ -1,7 +1,7 @@
 #!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: gdal_polygonize.py 1121758f74589f8850193a5baced7ab1335a4b39 2018-04-20 11:27:52 +0200 Even Rouault $
+#  $Id: gdal_polygonize.py 8e263710cb425c4a8b76b1f363b98be41ea0a983 2018-04-30 19:40:20 +1000 Ben Elliston $
 #
 #  Project:  GDAL Python Interface
 #  Purpose:  Application for converting raster data to a vector polygon layer.
@@ -66,7 +66,7 @@ def GetOutputDriversFor(filename):
         if (drv.GetMetadataItem(gdal.DCAP_CREATE) is not None or
             drv.GetMetadataItem(gdal.DCAP_CREATECOPY) is not None) and \
            drv.GetMetadataItem(gdal.DCAP_VECTOR) is not None:
-            if len(ext) > 0 and DoesDriverHandleExtension(drv, ext):
+            if ext and DoesDriverHandleExtension(drv, ext):
                 drv_list.append(drv.ShortName)
             else:
                 prefix = drv.GetMetadataItem(gdal.DMD_CONNECTION_PREFIX)
@@ -78,9 +78,9 @@ def GetOutputDriversFor(filename):
 
 def GetOutputDriverFor(filename):
     drv_list = GetOutputDriversFor(filename)
-    if len(drv_list) == 0:
+    if not drv_list:
         ext = GetExtension(filename)
-        if len(ext) == 0:
+        if not ext:
             return 'ESRI Shapefile'
         else:
             raise Exception("Cannot guess driver for %s" % filename)
@@ -93,7 +93,7 @@ def GetOutputDriverFor(filename):
 # =============================================================================
 
 
-format = None
+frmt = None
 options = []
 quiet_flag = 0
 src_filename = None
@@ -118,7 +118,7 @@ while i < len(argv):
 
     if arg == '-f' or arg == '-of':
         i = i + 1
-        format = argv[i]
+        frmt = argv[i]
 
     elif arg == '-q' or arg == '-quiet':
         quiet_flag = 1
@@ -160,8 +160,8 @@ while i < len(argv):
 if src_filename is None or dst_filename is None:
     Usage()
 
-if format is None:
-    format = GetOutputDriverFor(dst_filename)
+if frmt is None:
+    frmt = GetOutputDriverFor(dst_filename)
 
 if dst_layername is None:
     dst_layername = 'out'
@@ -199,9 +199,9 @@ elif isinstance(src_band_n, str) and src_band_n.startswith('mask,'):
 else:
     srcband = src_ds.GetRasterBand(src_band_n)
 
-if mask is 'default':
+if mask == 'default':
     maskband = srcband.GetMaskBand()
-elif mask is 'none':
+elif mask == 'none':
     maskband = None
 else:
     mask_ds = gdal.Open(mask)
@@ -222,9 +222,9 @@ except:
 # 	Create output file.
 # =============================================================================
 if dst_ds is None:
-    drv = ogr.GetDriverByName(format)
+    drv = ogr.GetDriverByName(frmt)
     if not quiet_flag:
-        print('Creating output %s of format %s.' % (dst_filename, format))
+        print('Creating output %s of format %s.' % (dst_filename, frmt))
     dst_ds = drv.CreateDataSource(dst_filename)
 
 # =============================================================================
